@@ -1,5 +1,4 @@
 
-
 import importlib
 import os
 import pickle
@@ -26,7 +25,9 @@ app_description_t = _("app_description_t")
 
 
 class SaveMenu():
-    def __init__(self, ps):
+    def __init__(
+            self,
+            ps):
         self.ps = ps
         self.surface = self.ps.surface
         self.title = _('Save game?')
@@ -63,7 +64,9 @@ class SaveMenu():
 
 
 class ContributorsMenu():
-    def __init__(self, ps):
+    def __init__(
+            self,
+            ps):
         self.ps = ps
         self.title = _('Contributors & Sponsors')
         self._menu = self.ps.get_default_menu(
@@ -79,11 +82,14 @@ class ContributorsMenu():
         contributors_table.add_row(
             ['Contributors', 'name', ' ', 'Sponsors', 'name'],
             cell_font=self._head_font)
+
         _len = list(range(max(len(app_contributors), len(app_sponsors))))
         for l, c, s in zip_longest(_len, app_contributors, app_sponsors):
             c, s = c or ' ', s or ' '
             contributors_table.add_row(
-                [l + 1, c, ' ', l + 1, s], cell_font=self._font)
+                [l + 1, c, ' ', l + 1, s],
+                cell_font=self._font)
+
         self._menu.add.button(
             _('Return to main menu'),
             pygame_menu.events.BACK,
@@ -93,7 +99,9 @@ class ContributorsMenu():
 
 
 class AboutMenu():
-    def __init__(self, ps):
+    def __init__(
+            self,
+            ps):
 
         self.ps = ps
         self.title = _('About')
@@ -102,25 +110,32 @@ class AboutMenu():
         self.app_version_font = get_default_font(20)
         self.app_description_font = get_default_font(22)
         self.app_url_font = get_default_font(20)
-        self.app_author_font = self.app_contributors_font = get_default_font(
-            20)
+        self.app_author_font = self.app_contributors_font = \
+            get_default_font(20)
         self.contributors_menu = ContributorsMenu(self.ps)
         self._label_font = get_default_font(32)
 
     def add_widgets(self):
-        self._menu.add.label(app_name, max_char=-1,
-                             font_name=self.app_name_font)
-        self._menu.add.label(app_version, max_char=-1,
-                             font_name=self.app_version_font)
-        self._menu.add.label(app_description_t, max_char=-1,
-                             font_name=self.app_description_font)
-        self._menu.add.url(app_url, font_name=self.app_url_font)
-        self._menu.add.label(_('Author'), max_char=-1,
-                             font_name=self._label_font)
-        self._menu.add.label(app_author, max_char=-1,
-                             font_name=self.app_author_font)
+        self._menu.add.label(
+            app_name, max_char=-1,
+            font_name=self.app_name_font)
+        self._menu.add.label(
+            app_version, max_char=-1,
+            font_name=self.app_version_font)
+        self._menu.add.label(
+            app_description_t, max_char=-1,
+            font_name=self.app_description_font)
+        self._menu.add.url(
+            app_url, font_name=self.app_url_font)
+        self._menu.add.label(
+            _('Author'), max_char=-1,
+            font_name=self._label_font)
+        self._menu.add.label(
+            app_author, max_char=-1,
+            font_name=self.app_author_font)
 
         self.contributors_menu.add_widgets()
+
         self._menu.add.button(
             _('Contributors & Sponsors'),
             self.contributors_menu._menu,
@@ -133,9 +148,15 @@ class AboutMenu():
 
 
 class PlayMenu():
-    def __init__(self, ps):
+    def __init__(
+            self,
+            ps,
+            player_name=None):
         self.ps = ps
         self.title = _('Play Game')
+        self.player_name = self.ps.player_name = \
+            player_name or _('default_name')
+        self.player_name_text_input = None
         self._menu = self.ps.get_default_menu(self.title)
         self.subjects = self.ps.subjects
         self.subject_games = self.ps.subject_games
@@ -154,15 +175,21 @@ class PlayMenu():
         self.help_lael_bg = (228, 0, 252, 30)
         self.help_lael_border_color = (228, 0, 252, 200)
 
+    def set_name(self, name):
+        self.player_name = name
+        self.player_name_text_input._update_input_string(self.player_name)
+        self.ps.player_name = self.player_name
+
     def add_widgets(self):
-        self._menu.add.text_input(
+        self.player_name_text_input = self._menu.add.text_input(
             title=_('Name :'),
-            default=_('_name_'),
+            default=self.player_name,
             font_name=self.ps.font_path)
 
         self.subject_dropselect = self._menu.add.dropselect(
             title=_('Subject :'),
-            items=[(s.name_t, index)for index, s in enumerate(self.subjects)],
+            items=[(s.name_t, index) for index, s in
+                   enumerate(self.subjects)],
             font_name=self.ps.font_path,
             default=0,
             selection_box_bgcolor=self.selection_box_bgcolor,
@@ -171,8 +198,8 @@ class PlayMenu():
         )
         self.subject_game_dropselect = self._menu.add.dropselect(
             title=_('Game :'),
-            items=[(g.name_t, index) for index, g in enumerate(
-                self.subject_games)],
+            items=[(g.name_t, index) for index, g in
+                   enumerate(self.subject_games)],
             font_name=self.ps.font_path,
             default=0,
             selection_box_bgcolor=self.selection_box_bgcolor,
@@ -191,20 +218,24 @@ class PlayMenu():
             onchange=self.on_difficulty_dropselect_change
         )
         self.update_selection_box_width()
+        self.set_difficulty_index()
 
         self._menu.add.button(
             _('Play'),
             self.play_btn_onreturn,
             font_name=self.ps.font_path)
+
         self.continue_button = self._menu.add.button(
             _('Continue'),
             self.continue_btn_onreturn,
             font_name=self.ps.font_path)
         self.update_continue_button()
+
         self._menu.add.button(
             _('Return to main menu'),
             pygame_menu.events.BACK,
             font_name=self.ps.font_path)
+
         self.help_lael = self._menu.add.label(
             '', font_name=self.help_lael_font)
         self.update_help_lael()
@@ -214,6 +245,7 @@ class PlayMenu():
                 self.subject_dropselect,
                 self.subject_game_dropselect,
                 self.difficulty_dropselect]:
+
             ds._selection_box_width = max(
                 [b.get_width() for b in ds._option_buttons]
             ) + ds._selection_box_inflate[0]
@@ -281,8 +313,9 @@ class PlayMenu():
         self.update_help_lael()
 
     def set_difficulty_index(self, index=0):
-        self.difficulty_index = self.ps.difficulty_index = \
-            index if index != 0 else self.subject_game.default_difficulty_index
+        self.difficulty_index = \
+            self.ps.difficulty_index = index if index != 0 else \
+            self.subject_game.default_difficulty_index
         self.update_difficulty_dropselect()
 
 
@@ -310,10 +343,11 @@ class PrimarySchool():
     def __init__(self):
         pygame.init()
         self.running = True
-        self.surface = pygame.display.set_mode((0, 0), pygame.FULLSCREEN)
+        self.surface = pygame.display.set_mode(
+            (0, 0), pygame.RESIZABLE)
         self.w_width, self.w_height = self.surface.get_size()
-        self.w_width_of_2, self.w_height_of_2 = self.w_width / 2, \
-            self.w_height / 2
+        self.w_width_of_2, self.w_height_of_2 = \
+            self.w_width / 2, self.w_height / 2
         self.w_centrex_y = [self.w_width_of_2, self.w_height]
         self.FPS = 30
         self.clock = pygame.time.Clock()
@@ -353,8 +387,10 @@ class PrimarySchool():
         theme.title_font = theme.widget_font = self.font
         theme.title_bar_style = pygame_menu.widgets.MENUBAR_STYLE_NONE
         theme.background_color = self.get_bg_img()
-        return pygame_menu.Menu(title, self.w_width, self.w_height,
-                                theme=theme, **kwargs)
+        return pygame_menu.Menu(
+            title,
+            self.w_width, self.w_height,
+            theme=theme, **kwargs)
 
     def clear_screen(self):
         self.surface.fill((255, 255, 255))
